@@ -12,6 +12,7 @@ dash_core_files = []
 dash_sparql_files = []
 dash_triple_rules_files = []
 dash_sparql_rules_files = []
+dash_expression_files = []
 dash_target_files = []
 dash_fn_files = []
 
@@ -138,7 +139,7 @@ def test_dash_validate_all_triple_rules(target_file, shacl_file):
     print(v_text)
     return True
 
-# Get all triple-rules tests.
+# Get all SHACL-AF sh:target tests.
 for x in walk(path.join(dash_files_dir, 'target')):
     for y in glob.glob(path.join(x[0], '*.test.ttl')):
         dash_target_files.append((y, None))
@@ -179,6 +180,47 @@ def test_dash_validate_target(target_file, shacl_file):
     print(v_text)
     return True
 
+# Get all SHACL-AF sh:expression tests.
+for x in walk(path.join(dash_files_dir, 'expression')):
+    for y in glob.glob(path.join(x[0], '*.test.ttl')):
+        dash_expression_files.append((y, None))
+@pytest.mark.parametrize('target_file, shacl_file', dash_expression_files)
+def test_dash_validate_expression(target_file, shacl_file):
+    test_name = shacl_file or target_file
+    try:
+        val, _, v_text = pyshacl.validate(
+            target_file, shacl_graph=shacl_file, advanced=True, inference='rdfs', check_dash_result=True, debug=True, meta_shacl=False)
+    except NotImplementedError as ne:
+        for ani in ALLOWABLE_NOT_IMPLEMENTED:
+            if test_name.endswith(ani):
+                v_text = "Skipping not implemented feature in test: {}".format(test_name)
+                print(v_text)
+                val = True
+                break
+        else:
+            print(ne)
+            val = False
+            v_text = ""
+    except ReportableRuntimeError as e:
+        import traceback
+        print(e)
+        traceback.print_tb(e.__traceback__)
+        val = False
+        v_text = ""
+    try:
+        assert val
+    except AssertionError as ae:
+        for af in ALLOWABLE_FAILURES:
+            if test_name.endswith(af):
+                v_text = "Allowing failure in test: {}".format(test_name)
+                print(v_text)
+                break
+        else:
+            raise ae
+
+    print(v_text)
+    return True
+
 # Get all SHACLFunction tests
 for x in walk(path.join(dash_files_dir, 'function')):
     for y in glob.glob(path.join(x[0], '*.test.ttl')):
